@@ -5,8 +5,7 @@
 ##
 ## Babble is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 2 of the License, or
-## (at your option) any later version.
+## the Free Software Foundation; version 2 dated June, 1991.
 ##
 ## Babble is distributed in the hope that it will be useful, but WITHOUT
 ## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -125,10 +124,10 @@ date. This can be turned off with this knob.
 =cut
 
 sub output {
-	my ($self, $babble, %params) = @_;
+	my ($self, $babble, $params) = @_;
 
 	$self->_merge_params
-		($babble, \%params,
+		($babble, $params,
 		 {
 			 -template => $self->_find_template ('advogato'),
 			 meta_css_link => "advogato.css"
@@ -136,7 +135,7 @@ sub output {
 	 );
 
 
-	return Babble::Output::HTML->output ($babble, %params);
+	return Babble::Output::HTML->output ($babble, $params);
 }
 
 =pod
